@@ -2325,9 +2325,16 @@ int main(int argc, char **argv)
 					break;
 
 				case 'V':
-					/* Print version number and exit */
-					print_version();
-					break;
+					{
+						char *iostat_env[] = {ENV_POSIXLY_CORRECT,
+								      ENV_COLORS,
+								      ENV_COLORS_SGR,
+								      ENV_TIME_FMT};
+#define IOSTAT_ENV_NR	4
+						/* Print environment contents, version number and exit */
+						print_version(iostat_env, IOSTAT_ENV_NR);
+						break;
+					}
 
 				default:
 					usage(argv[0]);
