@@ -47,6 +47,10 @@
 char *sccsid(void) { return (SCCSID); }
 #endif
 
+#ifdef TEST
+extern int __env;
+#endif
+
 unsigned long long uptime_cs[3] = {0, 0, 0};
 
 /* NOTE: Use array of _char_ for bitmaps to avoid endianness problems...*/
@@ -2262,6 +2266,12 @@ int main(int argc, char **argv)
 			}
 		}
 
+#ifdef TEST
+		else if (!strncmp(argv[opt], "--getenv", 8)) {
+			__env = TRUE;
+		}
+#endif
+
 		else if (!strncmp(argv[opt], "-", 1)) {
 			for (i = 1; *(argv[opt] + i); i++) {
 
@@ -2300,9 +2310,15 @@ int main(int argc, char **argv)
 					break;
 
 				case 'V':
-					/* Print version number */
-					print_version();
-					break;
+					{
+						char *mpstat_env[] = {ENV_COLORS,
+								      ENV_COLORS_SGR,
+								      ENV_TIME_FMT};
+#define MPSTAT_ENV_NR	3
+						/* Print environment contents, version number and exit */
+						print_version(mpstat_env, MPSTAT_ENV_NR);
+						break;
+					}
 
 				default:
 					usage(argv[0]);
