@@ -55,6 +55,10 @@
 char *sccsid(void) { return (SCCSID); }
 #endif
 
+#ifdef TEST
+extern int __env;
+#endif
+
 unsigned long long tot_jiffies[3] = {0, 0, 0};
 unsigned long long uptime_cs[3] = {0, 0, 0};
 struct st_pid *pid_list = NULL;
@@ -2638,6 +2642,13 @@ int main(int argc, char **argv)
 			opt++;
 		}
 
+#ifdef TEST
+		else if (!strncmp(argv[opt], "--getenv", 8)) {
+			__env = TRUE;
+			opt++;
+		}
+#endif
+
 		else if (!strncmp(argv[opt], "--dec=", 6) && (strlen(argv[opt]) == 7)) {
 			/* Check that the argument is a digit */
 			if (!isdigit(argv[opt][6])) {
@@ -2756,9 +2767,15 @@ int main(int argc, char **argv)
 					break;
 
 				case 'V':
-					/* Print version number and exit */
-					print_version();
-					break;
+					{
+						char *pidstat_env[] = {ENV_COLORS,
+								       ENV_COLORS_SGR,
+								       ENV_TIME_FMT};
+#define PIDSTAT_ENV_NR	3
+						/* Print environment contents, version number and exit */
+						print_version(pidstat_env, PIDSTAT_ENV_NR);
+						break;
+					}
 
 				case 'v':
 					/* Display some kernel tables values */
