@@ -1,6 +1,6 @@
 /*
  * pr_stats.h: Include file used to display system statistics
- * (C) 1999-2022 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 1999-2023 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _PR_STATS_H
@@ -100,6 +100,8 @@ __print_funct_t print_psiio_stats
 	(struct activity *, int, int, unsigned long long);
 __print_funct_t print_psimem_stats
 	(struct activity *, int, int, unsigned long long);
+__print_funct_t print_pwr_bat_stats
+	(struct activity *, int, int, unsigned long long);
 
 /* Functions used to display average statistics */
 __print_funct_t print_avg_memory_stats
@@ -134,5 +136,7 @@ __print_funct_t print_avg_psiio_stats
 	(struct activity *, int, int, unsigned long long);
 __print_funct_t print_avg_psimem_stats
 	(struct activity *, int, int, unsigned long long);
+__print_funct_t print_avg_pwr_bat_stats
+	(struct activity *, int, int, unsigned long long);
 
 #endif /* _PR_STATS_H */
