@@ -112,7 +112,7 @@ enum {
 #define S_F_SVG_HEIGHT		0x00200000
 #define S_F_SVG_PACKED		0x00400000
 #define S_F_SVG_SHOW_INFO	0x00800000
-/* Unused 			0x01000000 */
+#define S_F_MINMAX		0x01000000
 #define S_F_ZERO_OMIT		0x02000000
 #define S_F_SVG_SHOW_TOC	0x04000000
 #define S_F_FDATASYNC		0x08000000
@@ -153,6 +153,7 @@ enum {
 #define USE_OPTION_A(m)			(((m) & S_F_OPTION_A)     == S_F_OPTION_A)
 #define USE_OPTION_P(m)			(((m) & S_F_OPTION_P)     == S_F_OPTION_P)
 #define USE_OPTION_I(m)			(((m) & S_F_OPTION_I)     == S_F_OPTION_I)
+#define DISPLAY_MINMAX(m)		(((m) & S_F_MINMAX)       == S_F_MINMAX)
 
 #define AO_F_NULL		0x00000000
 
@@ -304,6 +305,8 @@ enum {
 #define NO_RANGE		0
 #define NON_FATAL		0
 #define FATAL			1
+#define H_MIN			0
+#define H_MAX			1
 #define C_SAR			0
 #define C_SADF			1
 #define ALL_ACTIVITIES		~0U
@@ -1127,8 +1130,15 @@ struct activity {
 	/*
 	 * Number of structures allocated in @buf[*]. This number should be greater
 	 * than or equal to @nr[*].
+	 * This also is the number of entries allocated for @spmin and @spmax. An entry
+	 * can contain several min or max values.
 	 */
 	__nr_t nr_allocated;
+	/*
+	 * Number of min and max values that will be saved for each item.
+	 * This will be used to size @spmin / @spmax areas (see below).
+	 */
+	int xnr;
 	/*
 	 * Size of an item.
 	 * This is the size of the corresponding structure, as read from or written
@@ -1159,6 +1169,23 @@ struct activity {
 	 * compute average).
 	 */
 	void *buf[3];
+	/*
+	 * Pointer on area where minimum and maximum values will be saved.
+	 * The size of each area is @nr * @nr2 * @xnr * sizeof(double).
+	 */
+	double *spmin;
+	double *spmax;
+	/*
+	 * Number of slots allocated in @spmin and @spmax buffers.
+	 * A slot can contain several values.
+	 * This number of slots is always greater than or equal to @nr_allocated.
+	 */
+	__nr_t nr_spalloc;
+	/*
+	 * Linked list containing the name of the devices in the order in which their
+	 * min and max values have been saved in @spmin and @spmax.
+	 */
+	struct sa_item *xdev_list;
 	/*
 	 * Bitmap for activities that need one. Such a bitmap is needed by activity
 	 * if @bitmap is not NULL.
@@ -1538,11 +1565,15 @@ int write_all
 
 #ifndef SOURCE_SADC
 int add_list_item
-	(struct sa_item **, char *, int);
+	(struct sa_item **, char *, int, int *);
 void allocate_bitmaps
 	(struct activity * []);
+void allocate_buffers
+	(struct activity *, size_t, uint64_t);
+void allocate_minmax_buf
+	(struct activity *, size_t, uint64_t);
 void allocate_structures
-	(struct activity * []);
+	(struct activity * [], uint64_t);
 int check_disk_reg
 	(struct activity *, int, int, int);
 void check_file_actlst
@@ -1584,6 +1615,8 @@ void get_itv_value
 	(struct record_header *, struct record_header *, unsigned long long *);
 void init_custom_color_palette
 	(void);
+void init_extrema_values
+	(struct activity *, int);
 int next_slice
 	(unsigned long long, unsigned long long, int, long);
 void parse_sa_devices
@@ -1600,6 +1633,8 @@ int parse_sar_q_opt
 	(char * [], int *, struct activity * []);
 int parse_timestamp
 	(char * [], int *, struct tstamp_ext *, const char *, uint64_t);
+void print_minmax
+	(int);
 void print_report_hdr
 	(uint64_t, struct tm *, struct file_header *);
 void print_sar_comment
@@ -1613,14 +1648,16 @@ int print_special_record
 	 struct file_header *, struct activity * [], struct report_format *, int, int);
 int read_file_stat_bunch
 	(struct activity * [], int, int, int, struct file_activity *, int, int,
-	 char *, struct file_magic *, enum on_eof);
+	 char *, struct file_magic *, enum on_eof, uint64_t);
 __nr_t read_nr_value
-	(int, char *, struct file_magic *, int, int, int);
+	(int, char *, struct file_magic *, int, int, int, __nr_t);
 int read_record_hdr
 	(int, void *, struct record_header *, struct file_header *, int, int,
 	 int, size_t, uint64_t, struct report_format *);
-void reallocate_all_buffers
-	(struct activity *, __nr_t);
+void reallocate_buffers
+	(struct activity *, __nr_t, uint64_t);
+void reallocate_minmax_buf
+	(struct activity *, __nr_t, uint64_t);
 void replace_nonprintable_char
 	(int, char *);
 int sa_fread
@@ -1629,7 +1666,12 @@ int sa_get_record_timestamp_struct
 	(uint64_t, struct record_header *, struct tstamp_ext *);
 int sa_open_read_magic
 	(int *, char *, struct file_magic *, int, int *, int);
-int search_list_item
+void save_extrema
+	(const unsigned int [], void *, void *, unsigned long long,
+	 double *, double *, int []);
+void save_minmax
+	(struct activity *, int, double);
+struct sa_item *search_list_item
 	(struct sa_item *, char *);
 void select_all_activities
 	(struct activity * []);
@@ -1642,6 +1684,6 @@ void set_hdr_rectime
 void set_record_timestamp_string
 	(uint64_t, char *, char *, int, struct tstamp_ext *);
 void swap_struct
-	(unsigned int [], void *, int);
+	(const unsigned int [], void *, int);
 #endif /* SOURCE_SADC undefined */
 #endif  /* _SA_H */
