@@ -93,7 +93,7 @@ void print_dbppc_restart(char *cur_date, char *cur_time, char *my_tz, char sep,
 						      : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
 										: "UTC"));
 	}
-	printf("%cLINUX-RESTART\t(%d CPU)\n",
+	printf("%cLINUX-RESTART\t(%u CPU)\n",
 	       sep, file_hdr->sa_cpu_nr > 1 ? file_hdr->sa_cpu_nr - 1 : 1);
 }
 
@@ -258,7 +258,7 @@ __printf_funct_t print_raw_restart(int *tab, int action, char *cur_date, char *c
 							      : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
 											: "UTC"));
 		}
-		printf("; LINUX-RESTART (%d CPU)\n",
+		printf("; LINUX-RESTART (%u CPU)\n",
 		       file_hdr->sa_cpu_nr > 1 ? file_hdr->sa_cpu_nr - 1 : 1);
 	}
 }
@@ -632,9 +632,9 @@ __printf_funct_t print_pcp_statistics(int *tab, int action, struct activity *act
 				      unsigned int id_seq[])
 {
 #ifdef HAVE_PCP
-	int i, p;
-
 	if (action & F_BEGIN) {
+		int i, p;
+
 		for (i = 0; i < NR_ACT; i++) {
 			if (!id_seq[i])
 				continue;	/* Activity not in file */
@@ -828,7 +828,7 @@ char *print_dbppc_timestamp(int fmt, struct file_header *file_hdr, char *cur_dat
 	char temp1[128], temp2[256];
 
 	/* This substring appears on every output line, preformat it here */
-	snprintf(temp1, sizeof(temp1), "%s%s%lld%s",
+	snprintf(temp1, sizeof(temp1), "%s%s%llu%s",
 		 file_hdr->sa_nodename, seps[isdb], itv, seps[isdb]);
 	if (strlen(cur_date)) {
 		snprintf(temp2, sizeof(temp2), "%s%s ", temp1, cur_date);
@@ -1042,10 +1042,10 @@ __tm_funct_t print_raw_timestamp(void *parm, int action, char *cur_date,
 				 PRINT_LOCAL_TIME(flags) ? my_tz
 							 : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
 										   : "UTC"));
-			}
-			else {
-				snprintf(pre, sizeof(pre), "%s", cur_time);
-			}
+		}
+		else {
+			snprintf(pre, sizeof(pre), "%s", cur_time);
+		}
 		pre[sizeof(pre) - 1] = '\0';
 
 		return pre;
@@ -1112,20 +1112,16 @@ __printf_funct_t print_xml_header(void *parm, int action, char *dfile, char *my_
 {
 	struct tm rectime, loc_t;
 	time_t t = file_hdr->sa_ust_time;
-	char cur_time[TIMESTAMP_LEN];
 	int *tab = (int *) parm;
 
 	if (action & F_BEGIN) {
-		printf("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
-		printf("<!DOCTYPE sysstat PUBLIC \"DTD v%s sysstat //EN\"\n",
-		       XML_DTD_VERSION);
-		printf("\"http://pagesperso-orange.fr/sebastien.godard/sysstat-%s.dtd\">\n",
-		       XML_DTD_VERSION);
+		char cur_time[TIMESTAMP_LEN];
 
+		printf("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
 		xprintf(*tab, "<sysstat\n"
-			      "xmlns=\"http://pagesperso-orange.fr/sebastien.godard/sysstat\"\n"
+			      "xmlns=\"https://sysstat.github.io\"\n"
 			      "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n"
-			      "xsi:schemaLocation=\"http://pagesperso-orange.fr/sebastien.godard sysstat.xsd\">");
+			      "xsi:schemaLocation=\"https://sysstat.github.io https://sysstat.github.io/sysstat.xsd\">");
 
 		xprintf(++(*tab), "<sysdata-version>%s</sysdata-version>",
 			XML_DTD_VERSION);
@@ -1183,10 +1179,11 @@ __printf_funct_t print_json_header(void *parm, int action, char *dfile, char *my
 {
 	struct tm rectime, loc_t;
 	time_t t = file_hdr->sa_ust_time;
-	char cur_time[TIMESTAMP_LEN];
 	int *tab = (int *) parm;
 
 	if (action & F_BEGIN) {
+		char cur_time[TIMESTAMP_LEN];
+
 		xprintf(*tab, "{\"sysstat\": {");
 
 		xprintf(++(*tab), "\"hosts\": [");
@@ -1241,14 +1238,14 @@ __printf_funct_t print_hdr_header(void *parm, int action, char *dfile, char *my_
 				  struct activity *act[], unsigned int id_seq[],
 				  struct file_activity *file_actlst)
 {
-	int i, p;
-	struct tm rectime, loc_t;
-	time_t t = file_hdr->sa_ust_time;
-	struct file_activity *fal;
-	char cur_time[TIMESTAMP_LEN];
-
 	/* Actions F_MAIN and F_END ignored */
 	if (action & F_BEGIN) {
+		struct tm rectime, loc_t;
+		time_t t = file_hdr->sa_ust_time;
+		int i, p;
+		char cur_time[TIMESTAMP_LEN];
+		struct file_activity *fal;
+
 		printf(_("System activity data file: %s (%#x)\n"),
 		       dfile, file_magic->format_magic);
 
@@ -1277,13 +1274,13 @@ __printf_funct_t print_hdr_header(void *parm, int action, char *dfile, char *my_
 		if (gmtime_r(&t, &loc_t) != NULL) {
 			printf(_("File time: "));
 			strftime(cur_time, sizeof(cur_time), "%T", &loc_t);
-			printf("%s UTC (%lld)\n", cur_time, file_hdr->sa_ust_time);
+			printf("%s UTC (%llu)\n", cur_time, file_hdr->sa_ust_time);
 		}
 
 		printf(_("Timezone: %s\n"), file_hdr->sa_tzname);
 
 		/* File composition: file_header, file_activity, record_header */
-		printf(_("File composition: (%d,%d,%d),(%d,%d,%d),(%d,%d,%d)\n"),
+		printf(_("File composition: (%u,%u,%u),(%u,%u,%u),(%u,%u,%u)\n"),
 		       file_magic->hdr_types_nr[0], file_magic->hdr_types_nr[1], file_magic->hdr_types_nr[2],
 		       file_hdr->act_types_nr[0], file_hdr->act_types_nr[1], file_hdr->act_types_nr[2],
 		       file_hdr->rec_types_nr[0], file_hdr->rec_types_nr[1], file_hdr->rec_types_nr[2]);
@@ -1301,7 +1298,7 @@ __printf_funct_t print_hdr_header(void *parm, int action, char *dfile, char *my_
 
 			p = get_activity_position(act, fal->id, RESUME_IF_NOT_FOUND);
 
-			printf("%02d: [%02x] ", fal->id, fal->magic);
+			printf("%02u: [%02x] ", fal->id, fal->magic);
 			if (p >= 0) {
 				printf("%-20s", act[p]->name);
 			}
@@ -1312,7 +1309,7 @@ __printf_funct_t print_hdr_header(void *parm, int action, char *dfile, char *my_
 			if (fal->nr2 > 1) {
 				printf("x%d", fal->nr2);
 			}
-			printf("\t(%d,%d,%d)", fal->types_nr[0], fal->types_nr[1], fal->types_nr[2]);
+			printf("\t(%u,%u,%u)", fal->types_nr[0], fal->types_nr[1], fal->types_nr[2]);
 			if ((p >= 0) && (act[p]->magic != fal->magic)) {
 				printf(_(" \t[Unknown format]"));
 			}
@@ -1348,8 +1345,6 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile, char *my_
 	struct svg_hdr_parm *hdr_parm = (struct svg_hdr_parm *) parm;
 	struct tm rectime;
 	time_t t = file_hdr->sa_ust_time;
-	unsigned int height = 0, ht = 0;
-	int i, p;
 
 	if (action & F_BEGIN) {
 		printf("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
@@ -1365,6 +1360,8 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile, char *my_
 	}
 
 	if (action & F_MAIN) {
+		unsigned int height;
+
 		if (SET_CANVAS_HEIGHT(flags)) {
 			/*
 			 * Option "-O height=..." used: @graph_nr is
@@ -1381,7 +1378,7 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile, char *my_
 			/* Min canvas height is 100 (at least to display "No data") */
 			height = 100;
 		}
-		printf(" width=\"%d\" height=\"%d\""
+		printf(" width=\"%d\" height=\"%u\""
 		       " fill=\"black\" stroke=\"#%06x\" stroke-width=\"1\">\n",
 		       SVG_T_XSIZE * (hdr_parm->views_per_row), height,
 		       svg_colors[palette][SVG_COL_DEFAULT_IDX]);
@@ -1394,6 +1391,9 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile, char *my_
 				 PLAIN_OUTPUT);
 		printf("</text>\n");
 		if (DISPLAY_TOC(flags)) {
+			unsigned int ht = 0;
+			int i, p;
+
 			for (i = 0; i < NR_ACT; i++) {
 				if (!id_seq[i])
 					continue;	/* Activity not in file */
@@ -1402,9 +1402,9 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile, char *my_
 				if (!IS_SELECTED(act[p]->options) || !act[p]->g_nr)
 					continue;	/* Activity not selected or no graph available */
 
-				printf("<a xlink:href=\"#g%d-0\" xlink:title=\"%s\">\n",
+				printf("<a xlink:href=\"#g%u-0\" xlink:title=\"%s\">\n",
 				       act[p]->id, act[p]->name);
-				printf("<text x=\"10\" y=\"%d\">%s</text></a>\n",
+				printf("<text x=\"10\" y=\"%u\">%s</text></a>\n",
 				       SVG_H_YSIZE + ht, act[p]->desc);
 				ht += SVG_C_YSIZE;
 			}
@@ -1455,7 +1455,6 @@ __printf_funct_t print_pcp_header(void *parm, int action, char *dfile, char *my_
 {
 #ifdef HAVE_PCP
 	char buf[64];
-	int rc;
 	unsigned long long utc_sec = file_hdr->sa_ust_time;
 
 	if (action & F_BEGIN) {
@@ -1497,6 +1496,8 @@ __printf_funct_t print_pcp_header(void *parm, int action, char *dfile, char *my_
 
 	if (action & F_END) {
 		if (action & F_BEGIN) {
+			int rc;
+
 			if ((rc = pmiWrite(utc_sec, 0)) < 0) {
 				fprintf(stderr, "PCP: pmiWrite: %s\n", pmiErrStr(rc));
 				exit(4);
@@ -1530,7 +1531,7 @@ __nr_t count_new_net_dev(struct activity *a, int curr)
 	for (i = 0; i < a->nr[curr]; i++) {
 		sndc = (struct stats_net_dev *) ((char *) a->buf[curr] + i * a->msize);
 
-		nr += add_list_item(&(a->item_list), sndc->interface, MAX_IFACE_LEN);
+		nr += add_list_item(&(a->item_list), sndc->interface, MAX_IFACE_LEN, NULL);
 	}
 
 	return nr;
@@ -1559,7 +1560,7 @@ __nr_t count_new_net_edev(struct activity *a, int curr)
 	for (i = 0; i < a->nr[curr]; i++) {
 		snedc = (struct stats_net_edev *) ((char *) a->buf[curr] + i * a->msize);
 
-		nr += add_list_item(&(a->item_list), snedc->interface, MAX_IFACE_LEN);
+		nr += add_list_item(&(a->item_list), snedc->interface, MAX_IFACE_LEN, NULL);
 	}
 
 	return nr;
@@ -1590,7 +1591,7 @@ __nr_t count_new_filesystem(struct activity *a, int curr)
 
 		nr += add_list_item(&(a->item_list),
 				    get_fs_name_to_display(a, flags, sfc),
-				    MAX_FS_LEN);
+				    MAX_FS_LEN, NULL);
 	}
 
 	return nr;
@@ -1619,7 +1620,7 @@ __nr_t count_new_fchost(struct activity *a, int curr)
 	for (i = 0; i < a->nr[curr]; i++) {
 		sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
 
-		nr += add_list_item(&(a->item_list), sfcc->fchost_name, MAX_FCH_LEN);
+		nr += add_list_item(&(a->item_list), sfcc->fchost_name, MAX_FCH_LEN, NULL);
 	}
 
 	return nr;
@@ -1652,7 +1653,7 @@ __nr_t count_new_disk(struct activity *a, int curr)
 				    get_device_name(sdc->major, sdc->minor, sdc->wwn, sdc->part_nr,
 						    DISPLAY_PRETTY(flags), DISPLAY_PERSIST_NAME_S(flags),
 						    USE_STABLE_ID(flags), NULL),
-				    MAX_DEV_LEN);
+				    MAX_DEV_LEN, NULL);
 	}
 
 	return nr;
@@ -1689,7 +1690,8 @@ __nr_t count_new_int(struct activity *a, int curr)
 	for (i = 0; i < a->nr2; i++) {
 		stc_cpuall_irq = (struct stats_irq *) ((char *) a->buf[curr] + i * a->msize);
 
-		nr += add_list_item(&(a->item_list), stc_cpuall_irq->irq_name, MAX_SA_IRQ_LEN);
+		nr += add_list_item(&(a->item_list), stc_cpuall_irq->irq_name,
+				    MAX_SA_IRQ_LEN, NULL);
 	}
 
 	return nr;
@@ -1722,7 +1724,7 @@ __nr_t count_new_bat(struct activity *a, int curr)
 		spbc = (struct stats_pwr_bat *) ((char *) a->buf[curr] + i * a->msize);
 
 		snprintf(bat_name, sizeof(bat_name), "BAT%d", (int) spbc->bat_id);
-		nr += add_list_item(&(a->item_list), bat_name, sizeof(bat_name));
+		nr += add_list_item(&(a->item_list), bat_name, sizeof(bat_name), NULL);
 	}
 
 	return nr;
