@@ -1421,6 +1421,16 @@ int main(int argc, char **argv)
 			}
 		}
 
+		else if (!strcmp(argv[opt], "-V")) {
+			char *sar_env[] = {ENV_COLORS,
+					   ENV_COLORS_SGR,
+					   ENV_REPEAT_HEADER,
+					   ENV_TIME_DEFTM,
+					   ENV_TIME_FMT};
+#define SAR_ENV_NR	5
+			print_version(sar_env, SAR_ENV_NR);
+		}
+
 		else if (!strcmp(argv[opt], "-o")) {
 			if (to_file[0]) {
 				/* Output file already specified */
