@@ -65,6 +65,7 @@ char *sccsid(void) { return (SCCSID); }
 
 #ifdef TEST
 void int_handler(int n) { return; }
+extern int __env;
 #endif
 
 int cpu_nr = 0;		/* Nb of processors on the machine */
@@ -626,6 +627,13 @@ int main(int argc, char **argv)
 			opt++;
 		}
 
+#ifdef TEST
+		else if (!strncmp(argv[opt], "--getenv", 8)) {
+			__env = TRUE;
+			opt++;
+		}
+#endif
+
 		else if (!strncmp(argv[opt], "-", 1)) {
 			for (i = 1; *(argv[opt] + i); i++) {
 
@@ -663,9 +671,15 @@ int main(int argc, char **argv)
 					break;
 
 				case 'V':
-					/* Print version number and exit */
-					print_version();
-					break;
+					{
+						char *tapestat_env[] = {ENV_COLORS,
+									ENV_COLORS_SGR,
+									ENV_TIME_FMT};
+#define TAPESTAT_ENV_NR	3
+						/* Print environment contents, version number and exit */
+						print_version(tapestat_env, TAPESTAT_ENV_NR);
+						break;
+					}
 
 				default:
 					usage(argv[0]);
