@@ -99,7 +99,7 @@ time_t get_localtime(struct tm *rectime, int d_off)
 	time_t timer;
 	struct tm *ltm;
 
-	time(&timer);
+	timer = time(NULL);
 	timer -= SEC_PER_DAY * d_off;
 	ltm = localtime(&timer);
 
@@ -128,7 +128,7 @@ time_t get_gmtime(struct tm *rectime, int d_off)
 	time_t timer;
 	struct tm *ltm;
 
-	time(&timer);
+	timer = time(NULL);
 	timer -= SEC_PER_DAY * d_off;
 	ltm = gmtime(&timer);
 
@@ -776,11 +776,12 @@ char *strtolower(char *str)
 */
 char *get_persistent_type_dir(char *type)
 {
-	static char dir[32];
+	static char dir[PATH_MAX];
+	int n;
 
-	snprintf(dir, 32, "%s-%s", DEV_DISK_BY, type);
+	n = snprintf(dir, sizeof(dir), "%s-%s", DEV_DISK_BY, type);
 
-	if (access(dir, R_OK)) {
+	if ((n >= sizeof(dir)) || access(dir, R_OK)) {
 		return (NULL);
 	}
 
@@ -801,11 +802,12 @@ char *get_persistent_type_dir(char *type)
 char *get_persistent_name_path(char *name)
 {
 	static char path[PATH_MAX];
+	int n;
 
-	snprintf(path, PATH_MAX, "%s/%s",
-		 get_persistent_type_dir(persistent_name_type), name);
+	n = snprintf(path, PATH_MAX, "%s/%s",
+		     get_persistent_type_dir(persistent_name_type), name);
 
-	if (access(path, F_OK)) {
+	if ((n >= sizeof(path)) || access(path, F_OK)) {
 		return (NULL);
 	}
 
@@ -1403,7 +1405,7 @@ int parse_values(char *strargv, unsigned char bitmap[], int max_val, const char
 			strncpy(range, t, 16);
 			range[15] = '\0';
 			valstr = t;
-			if ((s = index(range, '-')) != NULL) {
+			if ((s = strchr(range, '-')) != NULL) {
 				/* Possible range of values */
 				*s = '\0';
 				if (parse_valstr(range, max_val, &val_low) || (val_low < 0))
